package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.IntegrityMonitoringAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2020-04-28T12:18:09.226Z")
public class ComputerIntegrityMonitoringRuleAssignmentsRecommendationsApi {
  private ApiClient apiClient;

  public ComputerIntegrityMonitoringRuleAssignmentsRecommendationsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerIntegrityMonitoringRuleAssignmentsRecommendationsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Integrity Monitoring Rule IDs
   * Assign integrity monitoring rule IDs to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param integrityMonitoringRuleIDs The ID numbers of the integrity monitoring rules to add. (optional)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments addIntegrityMonitoringRuleIDsToComputer(Integer computerID, RuleIDs integrityMonitoringRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = integrityMonitoringRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling addIntegrityMonitoringRuleIDsToComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addIntegrityMonitoringRuleIDsToComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Assigned Integrity Monitoring Rule IDs
   * Lists all integrity monitoring rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments listIntegrityMonitoringRuleIDsOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listIntegrityMonitoringRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntegrityMonitoringRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove an Integrity Monitoring Rule ID
   * Unassign an integrity monitoring rule ID from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param integrityMonitoringRuleID The ID number of the integrity monitoring rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments removeIntegrityMonitoringRuleIDFromComputer(Integer computerID, Integer integrityMonitoringRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling removeIntegrityMonitoringRuleIDFromComputer");
    }
    
    // verify the required parameter 'integrityMonitoringRuleID' is set
    if (integrityMonitoringRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRuleID' when calling removeIntegrityMonitoringRuleIDFromComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeIntegrityMonitoringRuleIDFromComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/integritymonitoring/assignments/{integrityMonitoringRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "integrityMonitoringRuleID" + "\\}", apiClient.escapeString(integrityMonitoringRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Integrity Monitoring Rule IDs
   * Set integrity monitoring rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param integrityMonitoringRuleIDs The ID numbers of the integrity monitoring rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments setIntegrityMonitoringRuleIDsOnComputer(Integer computerID, RuleIDs integrityMonitoringRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = integrityMonitoringRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling setIntegrityMonitoringRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setIntegrityMonitoringRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
