package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ApplicationType;
import com.trendmicro.deepsecurity.model.ApplicationTypes;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2020-04-28T12:18:09.226Z")
public class ComputerIntrusionPreventionApplicationTypeDetailsApi {
  private ApiClient apiClient;

  public ComputerIntrusionPreventionApplicationTypeDetailsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerIntrusionPreventionApplicationTypeDetailsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe an intrusion prevention application type
   * Describe an intrusion prevention application type including computer-level overrides.
   * @param computerID The ID number of the computer. (required)
   * @param applicationTypeID The ID number of the application type. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationType
   * @throws ApiException if fails to make API call
   */
  public ApplicationType describeIntrusionPreventionApplicationTypeOnComputer(Integer computerID, Integer applicationTypeID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling describeIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'applicationTypeID' is set
    if (applicationTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'applicationTypeID' when calling describeIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "applicationTypeID" + "\\}", apiClient.escapeString(applicationTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationType> localVarReturnType = new GenericType<ApplicationType>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List intrusion prevention application types
   * Lists all intrusion prevention application types assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Show only application types assigned to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationTypes
   * @throws ApiException if fails to make API call
   */
  public ApplicationTypes listIntrusionPreventionApplicationTypesOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listIntrusionPreventionApplicationTypesOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntrusionPreventionApplicationTypesOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/applicationtypes".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationTypes> localVarReturnType = new GenericType<ApplicationTypes>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an intrusion prevention application type
   * Modify an intrusion prevention application type assigned to a computer. Any unset elements will be left unchanged.
   * @param computerID The ID number of the computer. (required)
   * @param applicationTypeID The ID number of the application type to modify. (required)
   * @param applicationType The settings of the application type to modify. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationType
   * @throws ApiException if fails to make API call
   */
  public ApplicationType modifyIntrusionPreventionApplicationTypeOnComputer(Integer computerID, Integer applicationTypeID, ApplicationType applicationType, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = applicationType;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling modifyIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'applicationTypeID' is set
    if (applicationTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'applicationTypeID' when calling modifyIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'applicationType' is set
    if (applicationType == null) {
      throw new ApiException(400, "Missing the required parameter 'applicationType' when calling modifyIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "applicationTypeID" + "\\}", apiClient.escapeString(applicationTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationType> localVarReturnType = new GenericType<ApplicationType>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset intrusion prevention application type overrides
   * Remove all overrides for an intrusion prevention application type from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param applicationTypeID The ID number of the application type to reset. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationType
   * @throws ApiException if fails to make API call
   */
  public ApplicationType resetIntrusionPreventionApplicationTypeOnComputer(Integer computerID, Integer applicationTypeID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling resetIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'applicationTypeID' is set
    if (applicationTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'applicationTypeID' when calling resetIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetIntrusionPreventionApplicationTypeOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "applicationTypeID" + "\\}", apiClient.escapeString(applicationTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationType> localVarReturnType = new GenericType<ApplicationType>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
