package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.InterfaceType;
import com.trendmicro.deepsecurity.model.InterfaceTypes;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2020-04-28T12:18:09.226Z")
public class InterfaceTypesApi {
  private ApiClient apiClient;

  public InterfaceTypesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public InterfaceTypesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create an Interface Type
   * Create a new interface type.
   * @param policyID The ID number of the policy. (required)
   * @param interfaceTypes The settings of the new interface type. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return InterfaceType
   * @throws ApiException if fails to make API call
   */
  public InterfaceType createInterfaceType(Integer policyID, InterfaceType interfaceTypes, String apiVersion) throws ApiException {
    Object localVarPostBody = interfaceTypes;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling createInterfaceType");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createInterfaceType");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InterfaceType> localVarReturnType = new GenericType<InterfaceType>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete an Interface Type
   * Delete an interface type by ID.
   * @param policyID The ID number of the policy. (required)
   * @param interfaceTypeID The ID number of the interface type to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteInterfaceType(Integer policyID, Integer interfaceTypeID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling deleteInterfaceType");
    }
    
    // verify the required parameter 'interfaceTypeID' is set
    if (interfaceTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'interfaceTypeID' when calling deleteInterfaceType");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteInterfaceType");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes/{interfaceTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "interfaceTypeID" + "\\}", apiClient.escapeString(interfaceTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe an Interface Type
   * Describe an interface type by ID.
   * @param policyID The ID number of the policy. (required)
   * @param interfaceTypeID The ID number of the interface type to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return InterfaceType
   * @throws ApiException if fails to make API call
   */
  public InterfaceType describeInterfaceType(Integer policyID, Integer interfaceTypeID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling describeInterfaceType");
    }
    
    // verify the required parameter 'interfaceTypeID' is set
    if (interfaceTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'interfaceTypeID' when calling describeInterfaceType");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeInterfaceType");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes/{interfaceTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "interfaceTypeID" + "\\}", apiClient.escapeString(interfaceTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InterfaceType> localVarReturnType = new GenericType<InterfaceType>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Interface Types
   * Lists all interface types.
   * @param policyID The ID number of the policy. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return InterfaceTypes
   * @throws ApiException if fails to make API call
   */
  public InterfaceTypes listInterfaceTypes(Integer policyID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listInterfaceTypes");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listInterfaceTypes");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InterfaceTypes> localVarReturnType = new GenericType<InterfaceTypes>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an Interface Type
   * Modify an interface type by ID. Any unset elements will be left unchanged.
   * @param policyID The ID number of the policy. (required)
   * @param interfaceTypeID The ID number of the interface type to modify. (required)
   * @param interfaceType The settings of the interface type to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return InterfaceType
   * @throws ApiException if fails to make API call
   */
  public InterfaceType modifyInterfaceType(Integer policyID, Integer interfaceTypeID, InterfaceType interfaceType, String apiVersion) throws ApiException {
    Object localVarPostBody = interfaceType;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling modifyInterfaceType");
    }
    
    // verify the required parameter 'interfaceTypeID' is set
    if (interfaceTypeID == null) {
      throw new ApiException(400, "Missing the required parameter 'interfaceTypeID' when calling modifyInterfaceType");
    }
    
    // verify the required parameter 'interfaceType' is set
    if (interfaceType == null) {
      throw new ApiException(400, "Missing the required parameter 'interfaceType' when calling modifyInterfaceType");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyInterfaceType");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes/{interfaceTypeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "interfaceTypeID" + "\\}", apiClient.escapeString(interfaceTypeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InterfaceType> localVarReturnType = new GenericType<InterfaceType>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Interface Types
   * Search for interface types using optional filters.
   * @param policyID The ID number of the policy. (required)
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return InterfaceTypes
   * @throws ApiException if fails to make API call
   */
  public InterfaceTypes searchInterfaceTypes(Integer policyID, SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling searchInterfaceTypes");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchInterfaceTypes");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/interfacetypes/search".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InterfaceTypes> localVarReturnType = new GenericType<InterfaceTypes>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
