package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.FirewallAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2020-04-28T12:18:09.226Z")
public class PolicyFirewallRuleAssignmentsApi {
  private ApiClient apiClient;

  public PolicyFirewallRuleAssignmentsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyFirewallRuleAssignmentsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Firewall Rule IDs
   * Assign firewall rule IDs to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleIDs The ID numbers of the firewall rules to add. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments addFirewallRuleIDsToPolicy(Integer policyID, RuleIDs firewallRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = firewallRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling addFirewallRuleIDsToPolicy");
    }
    
    // verify the required parameter 'firewallRuleIDs' is set
    if (firewallRuleIDs == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleIDs' when calling addFirewallRuleIDsToPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addFirewallRuleIDsToPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Firewall Rule IDs
   * Lists all firewall rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments listFirewallRuleIDsOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listFirewallRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listFirewallRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove a Firewall Rule ID
   * Unassign a firewall rule ID from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleID The ID number of the firewall rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments removeFirewallRuleIDFromPolicy(Integer policyID, Integer firewallRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling removeFirewallRuleIDFromPolicy");
    }
    
    // verify the required parameter 'firewallRuleID' is set
    if (firewallRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleID' when calling removeFirewallRuleIDFromPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeFirewallRuleIDFromPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/assignments/{firewallRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "firewallRuleID" + "\\}", apiClient.escapeString(firewallRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Firewall Rule IDs
   * Set firewall rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleIDs The ID numbers of the firewall rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments setFirewallRuleIDsOnPolicy(Integer policyID, RuleIDs firewallRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = firewallRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling setFirewallRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setFirewallRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
