package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.IntegrityMonitoringAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2020-04-28T12:18:09.226Z")
public class PolicyIntegrityMonitoringRuleAssignmentsRecommendationsApi {
  private ApiClient apiClient;

  public PolicyIntegrityMonitoringRuleAssignmentsRecommendationsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyIntegrityMonitoringRuleAssignmentsRecommendationsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Integrity Monitoring Rule IDs
   * Assign integrity monitoring rule IDs to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleIDs The ID numbers of the integrity monitoring rules to add. (optional)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments addIntegrityMonitoringRuleIDsToPolicy(Integer policyID, RuleIDs integrityMonitoringRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = integrityMonitoringRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling addIntegrityMonitoringRuleIDsToPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addIntegrityMonitoringRuleIDsToPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Integrity Monitoring Rule IDs
   * Lists all integrity monitoring rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments listIntegrityMonitoringRuleIDsOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listIntegrityMonitoringRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntegrityMonitoringRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove an Integrity Monitoring Rule ID
   * Unassign an integrity monitoring rule ID from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleID The ID number of the integrity monitoring rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments removeIntegrityMonitoringRuleIDFromPolicy(Integer policyID, Integer integrityMonitoringRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling removeIntegrityMonitoringRuleIDFromPolicy");
    }
    
    // verify the required parameter 'integrityMonitoringRuleID' is set
    if (integrityMonitoringRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRuleID' when calling removeIntegrityMonitoringRuleIDFromPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeIntegrityMonitoringRuleIDFromPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/assignments/{integrityMonitoringRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "integrityMonitoringRuleID" + "\\}", apiClient.escapeString(integrityMonitoringRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Integrity Monitoring Rule IDs
   * Set integrity monitoring rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleIDs The ID numbers of the integrity monitoring rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringAssignments
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringAssignments setIntegrityMonitoringRuleIDsOnPolicy(Integer policyID, RuleIDs integrityMonitoringRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = integrityMonitoringRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling setIntegrityMonitoringRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setIntegrityMonitoringRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringAssignments> localVarReturnType = new GenericType<IntegrityMonitoringAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
